@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding: utf-8
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -47,30 +47,31 @@ Thus 2.1.0a3 is hexversion 0x020100a3.
 __authors__ = ["Jérôme Kieffer", "V. Valls"]
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "21/01/2021"
+__date__ = "19/12/2025"
 __status__ = "production"
 __docformat__ = 'restructuredtext'
 __all__ = ["date", "version_info", "strictversion", "hexversion", "debianversion",
            "calc_hexversion", "citation"]
 
+
+from collections import namedtuple
+
+
 RELEASE_LEVEL_VALUE = {"dev": 0,
                        "alpha": 10,
                        "beta": 11,
                        "gamma": 12,
                        "rc": 13,
                        "final": 15}
-
-MAJOR = 0
-MINOR = 20
-MICRO = 0
+MAJOR = 2025
+MINOR = 12
+MICRO = 1
 RELEV = "final"  # <16
 SERIAL = 0  # <16
 
 date = __date__
 
-from collections import namedtuple
 _version_info = namedtuple("version_info", ["major", "minor", "micro", "releaselevel", "serial"])
-
 version_info = _version_info(MAJOR, MINOR, MICRO, RELEV, SERIAL)
 
 strictversion = version = debianversion = "%d.%d.%d" % version_info[:3]
@@ -128,4 +129,17 @@ hexversion = calc_hexversion(*version_info)
 citation = "doi:10.1107/S1600576715004306"
 
 if __name__ == "__main__":
-    print(version)
+    from argparse import ArgumentParser
+
+    parser = ArgumentParser(usage="print the version of the software")
+    parser.add_argument("--wheel", action="store_true", dest="wheel", default=None,
+                        help="print version formatted for wheel")
+    parser.add_argument("--debian", action="store_true", dest="debian", default=None,
+                        help="print version formatted for debian")
+    options = parser.parse_args()
+    if options.debian:
+        print(debianversion)
+    elif options.wheel:
+        print(strictversion)
+    else:
+        print(version)
